<?php
if (!function_exists('bubu_setup')) :
   function bubu_setup() {
       global $content_width;
       if (!isset($content_width)) {
           $content_width = 770;
       }

		/*
		 * Make Bubu WP Theme available for translation.
		 */

		load_theme_textdomain( 'bubu', get_template_directory() . '/languages' );
       // This theme styles the visual editor to resemble the theme style.
       add_editor_style(array('css/editor-style.css', bubu_font_url()));
       // Add RSS feed links to <head> for posts and comments.
       add_theme_support('automatic-feed-links');
       add_theme_support( 'title-tag' );
       add_theme_support('post-thumbnails');
       set_post_thumbnail_size(672, 372, true);
       add_image_size('bubu-full-width', 1038, 576, true);

		add_image_size('bubu-portfolio-image', 320, 260, true);
       // Bubu theme uses wp_nav_menu() in two locations.
       register_nav_menus(array(
           'primary' => __('Header Menu', 'bubu'),
           'secondary' => __('Footer Menu', 'bubu'),
       ));

	//custom background

	add_theme_support( 'custom-background', apply_filters( 'bubu_custom_background_args', array(
			'default-color' => 'f5f5f5',
		) ) );
       /*
	   * Switch default core markup for search form, comment form, and comments
	   * to output valid HTML5.
	   */
       add_theme_support('html5', array(
           'search-form', 'comment-form', 'comment-list',
       ));
       // Add support for featured content.
       add_theme_support('featured-content', array(
           'featured_content_filter' => 'bubu_get_featured_posts',
           'max_posts' => 6,
       ));
	   // Bubu theme uses its own gallery styles.
		add_filter('use_default_gallery_style', '__return_false');   }

endif;
// bubu_setup

add_action('after_setup_theme', 'bubu_setup');

/** Register Lato Google font for bubu theme.*/

function bubu_font_url() {
   $bubu_font_url = '';
   if ('off' !== _x('on', 'Lato font: on or off', 'bubu')) {
       $bubu_font_url = add_query_arg('family', urlencode('Lato:300,400,700,900,300italic,400italic,700italic'), "//fonts.googleapis.com/css");
   }
   return $bubu_font_url;
}

// thumbnail list

function bubu_thumbnail_image($content) {
   if (has_post_thumbnail())
       return the_post_thumbnail('thumbnail');

}
/*
* Set Theme Option variable as a global
*/
$bubu_options = get_option('bubu_theme_options');

global $bubu_options;

/** Register widget areas.*/

function bubu_widgets_init() {
   register_sidebar(array(
       'name' => __('Primary Sidebar', 'bubu'),
       'id' => 'sidebar-1',
       'description' => __('Main sidebar that appears on the right.', 'bubu'),
       'before_widget' => '<aside id="%1$s" class="widget %2$s">',
       'after_widget' => '</aside>',
       'before_title' => '<h3 class="sidebar-title">',
       'after_title' => '</h3>',
   ));
   register_sidebar(array(
       'name' => __('Footer Area One', 'bubu'),
       'id' => 'footer-1',
       'description' => __('Footer Area One that appears on the footer.', 'bubu'),
       'before_widget' => '<aside id="%1$s" class="widget %2$s">',
       'after_widget' => '</aside>',
       'before_title' => '<h3 class="widget-title">',
       'after_title' => '</h3>',
   ));
   register_sidebar(array(
       'name' => __('Footer Area Two', 'bubu'),
       'id' => 'footer-2',
       'description' => __('Footer Area Two that appears on the footer.', 'bubu'),
       'before_widget' => '<aside id="%1$s" class="widget %2$s">',
       'after_widget' => '</aside>',
       'before_title' => '<h3 class="widget-title">',
       'after_title' => '</h3>',
   ));
   register_sidebar(array(
       'name' => __('Footer Area Three', 'bubu'),
       'id' => 'footer-3',
       'description' => __('Footer Area Three that appears on the footer.', 'bubu'),
       'before_widget' => '<aside id="%1$s" class="widget %2$s">',
       'after_widget' => '</aside>',
       'before_title' => '<h3 class="widget-title">',
       'after_title' => '</h3>',
   ));
   register_sidebar(array(
       'name' => __('Footer Area Four', 'bubu'),
       'id' => 'footer-4',
       'description' => __('Footer Area Four that appears on the footer.', 'bubu'),
       'before_widget' => '<aside id="%1$s" class="widget %2$s">',
       'after_widget' => '</aside>',
       'before_title' => '<h3 class="widget-title">',
       'after_title' => '</h3>',
   ));

}

add_action('widgets_init', 'bubu_widgets_init');

/* Add default menu style if menu is not set from the backend.*/

function bubu_add_menuid($page_markup) {
   preg_match('/^<div class=\"([a-z0-9-_]+)\">/i', $page_markup, $bubu_matches);
   $bubu_divclass = '';
   if (!empty($bubu_matches)) {
       $bubu_divclass = $bubu_matches[1];
   }
   $bubu_toreplace = array('<div class="' . $bubu_divclass . ' pull-right-res">', '</div>');
   $bubu_replace = array('<div class="navbar-collapse collapse ">', '</div>');
   $bubu_new_markup = str_replace($bubu_toreplace, $bubu_replace, $page_markup);
   $bubu_new_markup = preg_replace('/<ul/', '<ul class="bubu-menu"', $bubu_new_markup);
   return $bubu_new_markup;

}

add_filter('wp_page_menu', 'bubu_add_menuid');

function bubu_excerpt_more() {
   return '...</p><a href="' . get_permalink() . '" class="read-button">'.__('Read more','bubu').'</a>';

}

add_filter("excerpt_more", "bubu_excerpt_more");

if (!function_exists('bubu_entry_meta')) :
/**
* Set up post entry meta.
* Meta information for current post: categories, tags, permalink, author, and date.
**/
   function bubu_entry_meta() {

		$bubu_options = get_option( 'bubu_theme_options' );

		if(!empty($bubu_options['entry-meta-by'])) { $bubu_by_text = $bubu_options['entry-meta-by']; } else { $bubu_by_text = __('by','bubu'); }

		if(!empty($bubu_options['entry-meta-in'])) { $bubu_in_text = $bubu_options['entry-meta-in']; } else { $bubu_in_text =  __('In','bubu'); }

		if(!empty($bubu_options['entry-meta-on'])) { $bubu_on_text = $bubu_options['entry-meta-on']; } else { $bubu_on_text = __('On','bubu'); }

		if(!empty($bubu_options['entry-meta-comments'])) { $bubu_comments_text = $bubu_options['entry-meta-comments']; } else { $bubu_comments_text = 'Comments'; }

		if(!empty($bubu_options['entry-meta-tags'])) { $bubu_tags_text = $bubu_options['entry-meta-tags']; } else { $bubu_tags_text = __('Tags','bubu'); }
       $bubu_date = sprintf('<li>'.$bubu_on_text.' <a href="%1$s" title="%2$s"><time datetime="%3$s">%4$s</time></a></li>', esc_url(get_day_link(get_post_time('Y'), get_post_time('m'), get_post_time('j'))), esc_attr(get_the_time()), esc_attr(get_the_date('c')), esc_html(get_the_date('M d,Y'))       );

       $bubu_author = sprintf('<li>'.$bubu_by_text.': <a href="%1$s" title="%2$s" >%3$s</a></li>', esc_url(get_author_posts_url(get_the_author_meta('ID'))), esc_attr(ucwords(get_the_author())), ucwords(get_the_author())
       );
       $bubu_comment = sprintf('<li>'.$bubu_comments_text.': %1$s', get_comments_number()
       );


       $bubu_tag_list = sprintf('%1$s</li>', get_the_tag_list( '<li>'.$bubu_tags_text.': ', ' , '));

	$bubu_category_list = sprintf('<li>'.$bubu_in_text.': %1$s</li>', get_the_category_list(' , '));

       printf('%1$s %2$s %3$s %4$s %5$s', $bubu_author, $bubu_category_list, $bubu_date, $bubu_comment, $bubu_tag_list);
   }

endif;

//fetch the title

function bubu_title() {
   if (is_category() || is_single()) {
       if (is_category())
           the_category();
       if (is_single())
           the_title();
   }
   elseif (is_page())
       the_title();
   elseif (is_search())
       echo the_search_query();

}

function bubu_left_sidebar_layout() {

	if ( is_page_template( 'page-template/left-sidebar.php' ) ) {
		echo "<style>.col-md-offset-1 { margin-right: 8.33333%; margin-left:0% }</style>";
	}
}

add_action('wp_head','bubu_left_sidebar_layout');

/***** Theme function file ******/

require get_template_directory() . "/theme-options/bubu.php";

require get_template_directory() . "/inc/enqueue_script.php";

require get_template_directory() . "/inc/tgm-plugins.php";

require get_template_directory() . "/inc/breadcrumbs.php";
