<?php

function bubu_options_init() {
    register_setting('bubu_options', 'bubu_theme_options', 'bubu_options_validate');
}

add_action('admin_init', 'bubu_options_init');

function bubu_options_validate($input) {
    /* -------------- Basic Settings---------------- */
    $input['logo'] = bubu_image_validation(esc_url_raw($input['logo']));
    $input['favicon'] = bubu_image_validation(esc_url_raw($input['favicon']));
    /* ------------Top Header Settings-------------- */
    $input['phone'] = sanitize_text_field($input['phone']);
    $input['email'] = sanitize_email($input['email']);
    $input['fburl'] = esc_url_raw($input['fburl']);
    $input['twitter'] = esc_url_raw($input['twitter']);
    $input['googleplus'] = esc_url_raw($input['googleplus']);
    $input['pinterest'] = esc_url_raw($input['pinterest']);
    /* -------------- Footer Settings----------------- */
    $input['footertext'] = sanitize_text_field($input['footertext']);
    /* -------------- Blog Settings----------------- */
    $input['blogtitle'] = sanitize_text_field($input['blogtitle']);
    $input['entry-meta-by'] = sanitize_text_field($input['entry-meta-by']);
    $input['entry-meta-on'] = sanitize_text_field($input['entry-meta-on']);
    $input['entry-meta-in'] = sanitize_text_field($input['entry-meta-in']);
    $input['entry-meta-comments'] = sanitize_text_field($input['entry-meta-comments']);
    $input['entry-meta-tags'] = sanitize_text_field($input['entry-meta-tags']);
    return $input;
}

function bubu_image_validation($bubu_imge_url) {
    $bubu_filetype = wp_check_filetype($bubu_imge_url);
    $bubu_supported_image = array('gif', 'jpg', 'jpeg', 'png', 'ico');
    if (in_array($bubu_filetype['ext'], $bubu_supported_image)) {
        return $bubu_imge_url;
    } else {
        return '';
    }
}

function bubu_framework_load_scripts() {
    wp_enqueue_media();
    wp_enqueue_style('bubu-framework', get_template_directory_uri() . '/theme-options/css/bubu_framework.css', false, '1.0.0');
    wp_enqueue_script('bubu-options-custom', get_template_directory_uri() . '/theme-options/js/bubu-custom.js', array('jquery'));
    wp_enqueue_script('bubu-media-uploader', get_template_directory_uri() . '/theme-options/js/media-uploader.js', array('jquery'));
}

add_action('admin_enqueue_scripts', 'bubu_framework_load_scripts');

function bubu_framework_menu_settings() {
    $bubu_menu = array(
        'page_title' => __('Bubu Theme Options', 'bubu'),
        'menu_title' => __('Theme Options', 'bubu'),
        'capability' => 'edit_theme_options',
        'menu_slug' => 'bubu_framework',
        'callback' => 'bubu_framework_page'
    );
    return apply_filters('bubu_framework_menu', $bubu_menu);
}

add_action('admin_menu', 'bubu_theme_options_add_page');

function bubu_theme_options_add_page() {
    $bubu_menu = bubu_framework_menu_settings();
    add_theme_page($bubu_menu['page_title'], $bubu_menu['menu_title'], $bubu_menu['capability'], $bubu_menu['menu_slug'], $bubu_menu['callback']);
}

function bubu_framework_page() {
    global $select_options;
    if (!isset($_REQUEST['settings-updated']))
        $_REQUEST['settings-updated'] = false;
    ?>
    <div class="bubu-themes">
        <form method="post" action="options.php" id="form-option" class="theme_option_ft">
            <div class="bubu-header">
                <div class="logo">
                    <?php
                    $bubu_image = get_template_directory_uri() . '/theme-options/images/logo.png';
                    echo "<a href='https://www.wordpressthemescase.com' target='_blank'><img src='" . esc_url($bubu_image) . "' alt='Wordpress Themes Case' /></a>";
                    ?>
                </div>
                <div class="header-right">
                    <h1><?php _e('Bubu Theme Options', 'bubu'); ?></h1>
                    <div class='btn-save'>
                        <input type="submit" class="button-primary" value="<?php _e('Save Options', 'bubu'); ?>" />
                    </div>
                </div>
            </div>
            <div class="bubu-details">
                <div class="bubu-options">
                    <div class="right-box">
                        <div class="nav-tab-wrapper">
                            <ul>
                                <li><a id="options-group-1-tab" class="nav-tab basicsettings-tab" title="<?php _e('Basic Settings', 'bubu'); ?>" href="#options-group-1"><?php _e('Basic Settings', 'bubu'); ?></a></li>
                                <li><a id="options-group-2-tab" class="nav-tab headersettings-tab" title="<?php _e('Header Settings', 'bubu'); ?>" href="#options-group-2"><?php _e('Top Header Settings', 'bubu'); ?></a></li>
                                <li><a id="options-group-3-tab" class="nav-tab footersettings-tab" title="<?php _e('Footer Settings', 'bubu'); ?>" href="#options-group-3"><?php _e('Footer Settings', 'bubu'); ?></a></li>
                                <li><a id="options-group-5-tab" class="nav-tab blogpagesettings-tab" title="<?php _e('Blog Page Settings', 'bubu'); ?>" href="#options-group-5"><?php _e('Blog Page Settings', 'bubu'); ?></a></li>
                            </ul>
                            </ul>
                        </div>
                    </div>
                    <div class="right-box-bg"></div>
                    <div class="postbox left-box">
                        <!--======================== F I N A L - - T H E M E - - O P T I O N ===================-->
                        <?php
                        settings_fields('bubu_options');
                        $bubu_options = get_option('bubu_theme_options');
                        ?>
                        <!-------------- Basic Settings----------------->
                        <div id="options-group-1" class="group basicsettings bubu-inner-tabs">
                            <div class="section theme-tabs theme-logo">
                                <a class="heading bubu-inner-tab active" href="javascript:void(0)"><?php _e('Logo (Recommended Size : 100px * 62px)', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group active">
                                    <div class="ft-control">
                                        <input id="logo-img" class="upload" type="text" name="bubu_theme_options[logo]" value="<?php
                                        if (!empty($bubu_options['logo'])) {
                                            echo esc_url($bubu_options['logo']);
                                        }
                                        ?>" placeholder="<?php _e('No file chosen', 'bubu'); ?>" />
                                        <input id="upload_image_button" class="upload-button button" type="button" value="<?php _e('Upload', 'bubu'); ?>" />
                                        <div class="screenshot" id="logo-image">
                                            <?php
                                            if (!empty($bubu_options['logo'])) {
                                                echo "<img src='" . esc_url($bubu_options['logo']) . "' /><a class='remove-image'>";

                                                echo "</a>";
                                            }
                                            ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="section theme-tabs theme-favicon"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Favicon', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="explain"><?php _e('Size of favicon should be exactly 32x32px for best results', 'bubu'); ?>.</div>
                                    <div class="ft-control">
                                        <input id="favicon-img" class="upload" type="text" name="bubu_theme_options[favicon]" value="<?php
                                        if (!empty($bubu_options['favicon'])) {
                                            echo esc_url($bubu_options['favicon']);
                                        }
                                        ?>" placeholder="<?php _e('No file chosen', 'bubu'); ?>" />
                                        <input id="upload_image_button1" class="upload-button button" type="button" value="<?php _e('Upload', 'bubu'); ?>" />
                                        <div class="screenshot" id="favicon-image">
                                            <?php
                                            if (!empty($bubu_options['favicon'])) {
                                                echo "<img src='" . esc_url($bubu_options['favicon']) . "' /><a class='remove-image'>";

                                                echo"</a>";
                                            }
                                            ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div id="section-remove-breadcrumbs" class="section theme-tabs theme-colors theme-fonts"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Breadcrumbs', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <input type="checkbox" id="bubu-remove-breadcrumbs" name="bubu_theme_options[remove-breadcrumbs]" <?php if (!empty($bubu_options['remove-breadcrumbs'])) { ?> checked="checked" <?php } ?> value="<?php _e('yes', 'bubu'); ?>">
                                        <label class="remove-breadcrumbs-class" for="bubu-remove-breadcrumbs"><?php _e('Check this if you want to hide the breadcrumbs', 'bubu'); ?>.</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <!-------------- Top Header Settings----------------->
                        <div id="options-group-2" class="group topheadersettings bubu-inner-tabs">
                            <div class="theme-tabs theme-colors theme-fonts">
                                <div style="display: block;">
                                    <div class="ft-control">
                                        <input type="checkbox" id="bubu-remove-top-header" name="bubu_theme_options[remove-top-header]" <?php if (!empty($bubu_options['remove-top-header'])) { ?> checked="checked" <?php } ?> value="<?php _e('yes', 'bubu'); ?>">
                                        <label class="remove-slider-class" for="bubu-remove-top-header"><?php _e('Check this if you want to hide the top header', 'bubu'); ?>.</label>
                                    </div>
                                </div>
                            </div>
                            <div id="section-phone" class="section theme-tabs theme-colors theme-fonts"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Phone', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Phone', 'bubu'); ?></div>
                                        <input type="text" id="phone" class="of-input" name="bubu_theme_options[phone]" size="32"  value="<?php
                                        if (!empty($bubu_options['phone'])) {
                                            echo esc_attr($bubu_options['phone']);
                                        }
                                        ?>">
                                    </div>
                                </div>
                            </div>
                            <div id="section-email" class="section theme-tabs theme-colors theme-fonts"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('E-mail', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('E-mail', 'bubu'); ?></div>
                                        <input type="text" id="email" class="of-input" validType="email" name="bubu_theme_options[email]" size="32"  value="<?php
                                        if (!empty($bubu_options['email'])) {
                                            echo sanitize_email($bubu_options['email']);
                                        }
                                        ?>">
                                    </div>
                                </div>
                            </div>
                            <div id="section-facebook" class="section theme-tabs"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Facebook Link', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Facebook profile or page URL like', 'bubu'); ?> http://facebook.com/username/</div>
                                        <input id="facebook" class="of-input" name="bubu_theme_options[fburl]" size="30" type="text" value="<?php
                                        if (!empty($bubu_options['fburl'])) {
                                            echo esc_url($bubu_options['fburl']);
                                        }
                                        ?>" />
                                    </div>
                                </div>
                            </div>
                            <div id="section-twitter" class="section theme-tabs"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Twitter Link', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Twitter profile or page URL like', 'bubu'); ?> http://www.twitter.com/username/</div>
                                        <input id="twitter" class="of-input" name="bubu_theme_options[twitter]" type="text" size="30" value="<?php
                                        if (!empty($bubu_options['twitter'])) {
                                            echo esc_url($bubu_options['twitter']);
                                        }
                                        ?>" />
                                    </div>
                                </div>
                            </div>
                            <div id="section-pinterest" class="section theme-tabs"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Pinterest Link', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Pinterest profile or page URL like', 'bubu'); ?> https://pinterest.com/username/</div>
                                        <input id="pinterest" class="of-input" name="bubu_theme_options[pinterest]" type="text" size="30" value="<?php
                                        if (!empty($bubu_options['pinterest'])) {
                                            echo esc_url($bubu_options['pinterest']);
                                        }
                                        ?>" />
                                    </div>
                                </div>
                            </div>
                            <div id="section-googleplus" class="section theme-tabs"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Google+ Link', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Google plus profile or page URL like', 'bubu'); ?> https://plus.google.com/username/</div>
                                        <input id="googleplus" class="of-input" name="bubu_theme_options[googleplus]" type="text" size="30" value="<?php
                                        if (!empty($bubu_options['googleplus'])) {
                                            echo esc_url($bubu_options['googleplus']);
                                        }
                                        ?>" />
                                    </div>
                                </div>
                            </div>
                            <div id="section-scroll-top-header" class="section theme-tabs theme-colors theme-fonts"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Display top header on scroll', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <input type="checkbox" id="bubu-scroll-top-header" name="bubu_theme_options[scroll-top-header]" <?php if (!empty($bubu_options['scroll-top-header'])) { ?> checked="checked" <?php } ?> value="<?php _e('yes', 'bubu'); ?>">
                                        <label class="scroll-top-header-class" for="bubu-scroll-top-header"><?php _e('Check this if you want to display top header on scroll', 'bubu'); ?>.</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <!-------------- Footer Settings----------------->
                        <div id="options-group-3" class="group footersettings bubu-inner-tabs">
                            <div id="section-footertext" class="section theme-tabs"> <a class="heading bubu-inner-tab active" href="javascript:void(0)"><?php _e('Copyright Text', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group active">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Copyright text for the footer of your website', 'bubu'); ?>.</div>
                                        <input type="text" id="footertext" class="of-input" name="bubu_theme_options[footertext]" size="32"  value="<?php
                                        if (!empty($bubu_options['footertext'])) {
                                            echo esc_attr($bubu_options['footertext']);
                                        }
                                        ?>">
                                    </div>
                                </div>
                            </div>
                            <div class="section theme-tabs theme-content"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Content', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Enter content for your site , you would like to display in the Footer', 'bubu'); ?>.</div>
                                        <textarea name="bubu_theme_options[footer-content]" rows="6" id="footer-content" class="of-input"><?php
                                            if (!empty($bubu_options['footer-content'])) {
                                                echo esc_attr($bubu_options['footer-content']);
                                            }
                                            ?></textarea>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <!-------------- Blog Settings----------------->
                        <div id="options-group-5" class="group blogsettings bubu-inner-tabs">
                            <div id="section-blogtitle" class="section theme-tabs"> <a class="heading bubu-inner-tab active" href="javascript:void(0)"><?php _e('Blog Title', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group active">
                                    <div class="ft-control">
                                        <input type="text" id="blogtitle" class="of-input" name="bubu_theme_options[blogtitle]" size="32"  value="<?php
                                        if (!empty($bubu_options['blogtitle'])) {
                                            echo esc_attr($bubu_options['blogtitle']);
                                        }
                                        ?>">
                                    </div>
                                </div>
                            </div>
                            <div id="section-entry-meta-by" class="section theme-tabs"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Entry meta by word', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Enter entry meta by word for your site , you would like to replace with current word', 'bubu'); ?>.</div>
                                        <input id="entry-meta-by" class="of-input" name="bubu_theme_options[entry-meta-by]" type="text" size="50" value="<?php
                                        if (!empty($bubu_options['entry-meta-by'])) {
                                            echo esc_attr($bubu_options['entry-meta-by']);
                                        }
                                        ?>" />
                                    </div>
                                </div>
                            </div>
                            <div id="section-entry-meta-in" class="section theme-tabs"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Entry meta in word', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Enter entry meta in word for your site , you would like to replace with current word', 'bubu'); ?>.</div>
                                        <input id="entry-meta-in" class="of-input" name="bubu_theme_options[entry-meta-in]" type="text" size="50" value="<?php
                                        if (!empty($bubu_options['entry-meta-in'])) {
                                            echo esc_attr($bubu_options['entry-meta-in']);
                                        }
                                        ?>" />
                                    </div>
                                </div>
                            </div>
                            <div id="section-entry-meta-on" class="section theme-tabs"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Entry meta on word', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Enter entry meta on word for your site , you would like to replace with current word', 'bubu'); ?>.</div>
                                        <input id="entry-meta-on" class="of-input" name="bubu_theme_options[entry-meta-on]" type="text" size="50" value="<?php
                                        if (!empty($bubu_options['entry-meta-on'])) {
                                            echo esc_attr($bubu_options['entry-meta-on']);
                                        }
                                        ?>" />
                                    </div>
                                </div>
                            </div>
                            <div id="section-entry-meta-comments" class="section theme-tabs"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Entry meta comments word', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Enter entry meta comments word for your site , you would like to replace with current word', 'bubu'); ?>.</div>
                                        <input id="entry-meta-comments" class="of-input" name="bubu_theme_options[entry-meta-comments]" type="text" size="50" value="<?php
                                        if (!empty($bubu_options['entry-meta-comments'])) {
                                            echo esc_attr($bubu_options['entry-meta-comments']);
                                        }
                                        ?>" />
                                    </div>
                                </div>
                            </div>
                            <div id="section-entry-meta-tags" class="section theme-tabs"> <a class="heading bubu-inner-tab" href="javascript:void(0)"><?php _e('Entry meta tags word', 'bubu'); ?></a>
                                <div class="bubu-inner-tab-group">
                                    <div class="ft-control">
                                        <div class="explain"><?php _e('Enter entry meta tags word for your site , you would like to replace with current word', 'bubu'); ?>.</div>
                                        <input id="entry-meta-tags" class="of-input" name="bubu_theme_options[entry-meta-tags]" type="text" size="50" value="<?php
                                        if (!empty($bubu_options['entry-meta-tags'])) {
                                            echo esc_attr($bubu_options['entry-meta-tags']);
                                        }
                                        ?>" />
                                    </div>
                                </div>
                            </div>
                        </div>
                        
    <div class="save-options"><h2><?php _e('Options saved successfully', 'bubu'); ?>.</h2></div>
    <?php
}
